@@ -1,8 +1,5 @@
 # --
-# Kernel/Modules/AdminEmail.pm - to send a email to all agents
-# Copyright (C) 2001-2010 OTRS AG, http://otrs.org/
-# --
-# $Id: AdminEmail.pm,v 1.48 2010-11-23 00:10:35 en Exp $
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -14,11 +11,10 @@ package Kernel::Modules::AdminEmail;
 use strict;
 use warnings;
 
+use Kernel::System::CustomerGroup;
+use Kernel::System::CustomerUser;
 use Kernel::System::Email;
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.48 $) [1];
-
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -49,8 +45,7 @@ sub Run {
     my ( %GetParam, %Errors );
 
     for my $Parameter (qw(From Subject Body Bcc GroupPermission NotifyCustomerUsers)) {
-        $Param{$Parameter}
-            = $Self->{ParamObject}->GetParam( Param => $Parameter )
+        $Param{$Parameter} = $Self->{ParamObject}->GetParam( Param => $Parameter )
             || $Param{$Parameter}
             || '';
     }
@@ -60,6 +55,9 @@ sub Run {
     # ------------------------------------------------------------ #
     if ( $Self->{Subaction} eq 'Send' ) {
 
+        # challenge token check for write action
+        $Self->{LayoutObject}->ChallengeTokenCheck();
+
         # check needed stuff
         for my $Needed (qw(From Subject Body GroupPermission)) {
             if ( !$Param{$Needed} ) {
@@ -186,9 +184,16 @@ sub Run {
                     return $Self->{LayoutObject}->ErrorScreen();
                 }
 
+                my $BccText = $Param{Bcc};
+                $BccText =~ s{(.*?),\s$}{$1}gsmx;
+                $BccText .= ".";
+
                 $Self->{LayoutObject}->Block(
                     Name => 'Sent',
-                    Data => \%Param,
+                    Data => {
+                        %Param,
+                        Bcc => $BccText,
+                    },
                 );
                 my $Output = $Self->{LayoutObject}->Header();
                 $Output .= $Self->{LayoutObject}->NavigationBar();
@@ -205,7 +210,6 @@ sub Run {
     # ------------------------------------------------------------ #
     # show mask
     # ------------------------------------------------------------ #
-    my $Reference;
 
     # add rich text editor
     if ( $Self->{LayoutObject}->{BrowserRichText} ) {
@@ -214,36 +218,31 @@ sub Run {
             Data => \%Param,
         );
     }
-
-    $Reference = defined( @{ $GetParam{UserIDs} } ) ? \@{ $GetParam{UserIDs} } : '';
     $Param{UserOption} = $Self->{LayoutObject}->BuildSelection(
-        Data => { $Self->{UserObject}->UserList( Valid => 1 ) },
-        Name => 'UserIDs',
-        Size => 6,
-        Multiple   => 1,
-        SelectedID => $Reference,
-        Class      => $Errors{BccInvalid} || '',
+        Data        => { $Self->{UserObject}->UserList( Valid => 1 ) },
+        Name        => 'UserIDs',
+        Size        => 6,
+        Multiple    => 1,
+        Translation => 0,
+        Class => $Errors{BccInvalid} || '',
     );
 
-    $Reference = defined( @{ $GetParam{GroupIDs} } ) ? \@{ $GetParam{GroupIDs} } : '';
     $Param{GroupOption} = $Self->{LayoutObject}->BuildSelection(
-        Data => { $Self->{GroupObject}->GroupList( Valid => 1 ) },
-        Size => 6,
-        Name => 'GroupIDs',
-        Multiple   => 1,
-        SelectedID => $Reference,
-        Class      => $Errors{BccInvalid} || '',
+        Data        => { $Self->{GroupObject}->GroupList( Valid => 1 ) },
+        Size        => 6,
+        Name        => 'GroupIDs',
+        Multiple    => 1,
+        Translation => 0,
+        Class => $Errors{BccInvalid} || '',
     );
-
     my %RoleList = $Self->{GroupObject}->RoleList( Valid => 1 );
-    $Reference = defined( @{ $GetParam{RoleIDs} } ) ? \@{ $GetParam{RoleIDs} } : '';
     $Param{RoleOption} = $Self->{LayoutObject}->BuildSelection(
-        Data       => \%RoleList,
-        Size       => 6,
-        Name       => 'RoleIDs',
-        Multiple   => 1,
-        SelectedID => $Reference,
-        Class      => $Errors{BccInvalid} || '',
+        Data        => \%RoleList,
+        Size        => 6,
+        Name        => 'RoleIDs',
+        Multiple    => 1,
+        Translation => 0,
+        Class       => $Errors{BccInvalid} || '',
     );
 
     $Self->{LayoutObject}->Block(
@@ -254,7 +253,7 @@ sub Run {
         },
     );
 
-    if ( scalar( keys %RoleList ) ) {
+    if (%RoleList) {
         $Self->{LayoutObject}->Block(
             Name => 'RoleRecipients',
             Data => \%Param,
