@@ -1,6 +1,5 @@
 # --
-# Kernel/Output/HTML/ArticleCheckSMIME.pm
-# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -15,6 +14,16 @@ use warnings;
 use Kernel::System::Crypt;
 use Kernel::System::EmailParser;
 
+our @ObjectDependencies = (
+    'Kernel::Config',
+    'Kernel::Output::HTML::Layout',
+    'Kernel::System::DB',
+    'Kernel::System::Encode',
+    'Kernel::System::Log',
+    'Kernel::System::Main',
+    'Kernel::System::Ticket',
+);
+
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -23,10 +32,15 @@ sub new {
     bless( $Self, $Type );
 
     # get needed objects
-    for (
-        qw(ConfigObject LogObject EncodeObject MainObject DBObject LayoutObject UserID TicketObject ArticleID)
-        )
-    {
+    $Self->{ConfigObject} = $Param{ConfigObject} || $Kernel::OM->Get('Kernel::Config');
+    $Self->{LogObject}    = $Param{LogObject}    || $Kernel::OM->Get('Kernel::System::Log');
+    $Self->{EncodeObject} = $Param{EncodeObject} || $Kernel::OM->Get('Kernel::System::Encode');
+    $Self->{MainObject}   = $Param{MainObject}   || $Kernel::OM->Get('Kernel::System::Main');
+    $Self->{DBObject}     = $Param{DBObject}     || $Kernel::OM->Get('Kernel::System::DB');
+    $Self->{TicketObject} = $Param{TicketObject} || $Kernel::OM->Get('Kernel::System::Ticket');
+    $Self->{LayoutObject} = $Param{LayoutObject} || $Kernel::OM->Get('Kernel::Output::HTML::Layout');
+
+    for (qw(UserID ArticleID)) {
         if ( $Param{$_} ) {
             $Self->{$_} = $Param{$_};
         }
@@ -37,6 +51,7 @@ sub new {
             );
         }
     }
+
     return $Self;
 }
 
@@ -265,10 +280,11 @@ sub Check {
 
                 # compare sender email to signer email
                 my $SignerSenderMatch = 0;
+                SIGNER:
                 for my $Signer ( @{ $SignCheck{Signers} } ) {
                     if ( $OrigSender =~ m{\A \Q$Signer\E \z}xmsi ) {
                         $SignerSenderMatch = 1;
-                        last;
+                        last SIGNER;
                     }
                 }
 
@@ -330,19 +346,6 @@ sub Check {
             )
         {
 
-            # check if article is already verified
-            if ( $Param{Article}->{Body} ne '- no text message => see attachment -' ) {
-
-                # return result
-                push(
-                    @Return,
-                    {
-                        Key   => 'Signed',
-                        Value => 'Signature verified before!',
-                    }
-                );
-            }
-
             # check sign and get clear content
             %SignCheck = $Self->{CryptObject}->Verify(
                 Message => $Message,
@@ -394,10 +397,11 @@ sub Check {
 
                 # compare sender email to signer email
                 my $SignerSenderMatch = 0;
+                SIGNER:
                 for my $Signer ( @{ $SignCheck{Signers} } ) {
                     if ( $OrigSender =~ m{\A \Q$Signer\E \z}xmsi ) {
                         $SignerSenderMatch = 1;
-                        last;
+                        last SIGNER;
                     }
                 }
 
